"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientCache = void 0;
/**
 * @description Cache the API response
 */
class ClientCache {
    constructor(options) {
        Object.defineProperty(this, "cache", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: {}
        });
        Object.defineProperty(this, "sweepInterval", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: null
        });
        Object.defineProperty(this, "maxAge", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.maxAge = options?.maxAge || 60;
        this.sweepInterval = setInterval(() => {
            this.sweep();
        }, 1000 * this.maxAge).unref();
    }
    get size() {
        return Object.keys(this.cache).length;
    }
    sweep() {
        if (this.size === 0 && this.sweepInterval) {
            clearInterval(this.sweepInterval);
            this.sweepInterval = null;
        }
        for (const key in this.cache) {
            const cache = this.cache[key];
            if (cache && Date.now() - cache.timestamp > this.maxAge * 1000) {
                delete this.cache[key];
            }
        }
    }
    get(key) {
        if (this.has(key)) {
            const C = this.cache[key];
            return C?.value;
        }
        return {};
    }
    set(key, value) {
        this.cache[key] = {
            value,
            timestamp: Date.now(),
        };
    }
    has(key) {
        if (typeof this.cache[key] === "undefined")
            return false;
        return true;
    }
    delete(key) {
        delete this.cache[key];
    }
}
exports.ClientCache = ClientCache;
