"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RealTimeNotes = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const base_1 = require("./base");
const validate_1 = require("../utils/validate");
class RealTimeNotes extends base_1.BaseRoute {
    /**
     * @param {string} uid Genshin Impact game uid.
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = this.getFetchOptions(options);
        if (!(0, validate_1.validate)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new request_1.request({
            withDS: true,
        });
        instance.setLanguage(language);
        const res = await instance.get("dailyNote", {
            "x-rpc-client_type": "4",
            "x-rpc-app_version": "1.5.0",
            Cookie: cookie,
        }, {
            server: (0, getServer_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(uid, data);
        }
        return data;
    }
}
exports.RealTimeNotes = RealTimeNotes;
