"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.claimHistoryValidator = exports.getMonthValidator = exports.redeemValidator = exports.getAvatarValidator = exports.spiralAbyssValidator = exports.getDayRewardValidator = exports.validate = void 0;
const zod_1 = require("zod");
const validate = (key, options) => {
    const schema = zod_1.z.object({
        key: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ key, options });
    return true;
};
exports.validate = validate;
const getDayRewardValidator = (day, options) => {
    const schema = zod_1.z.object({
        day: zod_1.z.number(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ day, options });
    return true;
};
exports.getDayRewardValidator = getDayRewardValidator;
const spiralAbyssValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            previous: zod_1.z.boolean().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.spiralAbyssValidator = spiralAbyssValidator;
const getAvatarValidator = (characterId, options) => {
    const schema = zod_1.z.object({
        characterId: zod_1.z.number(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ characterId, options });
    return true;
};
exports.getAvatarValidator = getAvatarValidator;
const redeemValidator = (code, options) => {
    const schema = zod_1.z.object({
        code: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            uid: zod_1.z.string(),
            cookie_token: zod_1.z.string(),
        }),
    });
    schema.parse({ code, options });
    return true;
};
exports.redeemValidator = redeemValidator;
const getMonthValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            month: zod_1.z.number(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.getMonthValidator = getMonthValidator;
const claimHistoryValidator = (options) => {
    const schema = zod_1.z.object({
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            page: zod_1.z.number().optional(),
        }),
    });
    schema.parse({ options });
    return true;
};
exports.claimHistoryValidator = claimHistoryValidator;
